@@ -1,3 +1,5 @@
+import os
+
 SECRET_KEY = "-"
 
 INSTALLED_APPS = [
@@ -18,7 +20,13 @@ SIMPL_CHARACTER = "simpl.Character"
 SIMPL_PLAYER = "simpl.Player"
 
 DATABASES = {
-    "default": {"ENGINE": "django.db.backends.postgresql", "NAME": "simpl-test"}
+    "default": {
+        "ENGINE": "django.db.backends.postgresql",
+        "NAME": os.environ.get("POSTGRES_NAME", "simpl-test"),
+        "HOST": os.environ.get("POSTGRES_HOST", "localhost"),
+        "USER": os.environ.get("POSTGRES_USER", "postgres"),
+        "PASSWORD": os.environ.get("POSTGRES_PASSWORD", ""),
+    }
 }
 
 ROOT_URLCONF = "simpl.urls"
